@@ -12,9 +12,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from unittest import mock
+
 import fixtures
 import json
-import mock
 from mock import ANY
 import os
 
@@ -46,7 +47,7 @@ class TestChefExecutor(base.MuranoAgentTestCase, fixtures.TestWithFixtures):
         self.assertEqual(json.loads(node), self.get_node_atts())
 
     @mock.patch('subprocess.Popen')
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     @mock.patch('os.path.exists')
     @mock.patch('os.path.isdir')
     def test_cookbook(self, mock_isdir, mock_exist, open_mock,
@@ -69,7 +70,7 @@ class TestChefExecutor(base.MuranoAgentTestCase, fixtures.TestWithFixtures):
         self.chef_executor.run('test')
 
     @mock.patch('subprocess.Popen')
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     @mock.patch('os.path.exists')
     @mock.patch('os.path.isdir')
     def test_cookbook_error(self, mock_isdir, mock_exist, open_mock,
